==> ukui-search_4.0.6.1.orig.tar.gz: ukui-search-4.0.6.1/translations/ukui-search/appwidget/search_mn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo_CN">
<context>
    <name>UkuiSearch::BestListWidget</name>
    <message>
        <location filename="../../../frontend/view/best-list-view.cpp" line="388"/>
        <source>Best Matches</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkuiSearch::CreateIndexAskDialog</name>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="42"/>
        <source>ukui-search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="71"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="78"/>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="96"/>
        <source>Creating index can help you get results more quickly. Would you like to create one?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="107"/>
        <source>Don&apos;t remind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="118"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="120"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkuiSearch::MainWindow</name>
    <message>
        <location filename="../../../frontend/mainwindow.cpp" line="72"/>
        <source>ukui-search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/mainwindow.cpp" line="80"/>
        <source>Global Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchLineEdit</name>
    <message>
        <location filename="../../../frontend/control/search-line-edit.cpp" line="53"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkuiSearch::UkuiSearchGui</name>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="109"/>
        <source>Quit ukui-search application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="112"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="115"/>
        <source>unregister a plugin with &lt;pluginName&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="118"/>
        <source>register a plugin with &lt;pluginName&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="121"/>
        <source>move &lt;pluginName&gt; to the target pos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="124"/>
        <source>move plugin to &lt;index&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>search</name>
    <message>
        <location filename="../../../frontend/search-app-widget-plugin/provider/data/search.qml" line="115"/>
        <source>search</source>
        <translation>ᠡᠷᠢᠬᠦ</translation>
    </message>
</context>
</TS>

==> ukui-search_4.10.5.0.orig.tar.gz: ukui-search-4.10.5.0/translations/ukui-search/appwidget/search_mn.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo_CN">
<context>
    <name>UkuiSearch::BestListWidget</name>
    <message>
        <location filename="../../../frontend/view/best-list-view.cpp" line="389"/>
        <source>Best Matches</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkuiSearch::CreateIndexAskDialog</name>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="42"/>
        <source>ukui-search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="71"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="78"/>
        <source>close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="96"/>
        <source>Creating index can help you get results more quickly. Would you like to create one?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="107"/>
        <source>Don&apos;t remind me again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="118"/>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/control/create-index-ask-dialog.cpp" line="120"/>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkuiSearch::MainWindow</name>
    <message>
        <location filename="../../../frontend/mainwindow.cpp" line="73"/>
        <source>ukui-search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/mainwindow.cpp" line="81"/>
        <source>Search Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/mainwindow.cpp" line="84"/>
        <source>Global Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchLineEdit</name>
    <message>
        <location filename="../../../frontend/control/search-line-edit.cpp" line="53"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkuiSearch::UkuiSearchGui</name>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="111"/>
        <source>Quit ukui-search application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="114"/>
        <source>Show main window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="117"/>
        <source>unregister a plugin with &lt;pluginName&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="120"/>
        <source>register a plugin with &lt;pluginName&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="123"/>
        <source>move &lt;pluginName&gt; to the target pos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../frontend/ukui-search-gui.cpp" line="126"/>
        <source>move plugin to &lt;index&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>search</name>
    <message>
        <location filename="../../../frontend/search-app-widget-plugin/provider/data/search.qml" line="115"/>
        <source>search</source>
        <translation>ᠡᠷᠢᠬᠦ</translation>
    </message>
</context>
</TS>
